@@ -3,7 +3,7 @@ from google.cloud import bigquery
 from airflow_commons.glossary import COMMA
 from airflow_commons.logger import LOGGER
 from airflow_commons.sql_resources import (
-    GET_OLDEST_PARTITION_FIELD_SQL_FILE,
+    DEDUPLICATION_GET_OLDEST_PARTITION_FIELD_SQL_FILE,
     ARCHIVE_SOURCE_STATEMENT_FILE,
     ARCHIVE_DELETE_WHERE_STATEMENT_FILE,
 )
@@ -12,6 +12,7 @@ from airflow_commons.utils.bigquery_utils import (
     DEFAULT_LOCATION,
     connect,
     get_time_partition_field,
+    select,
     single_value_select,
     query,
     get_table_ref,
@@ -20,7 +21,6 @@ from airflow_commons.utils.file_utils import read_sql
 from airflow_commons.utils.sql_utils import (
     get_deduplication_source_statement,
     get_merge_sql,
-    get_oldest_partition_field_sql,
     get_delete_sql,
 )
 from airflow_commons.utils.time_utils import get_buffered_timestamp
@@ -42,8 +42,10 @@ def deduplicate(
     source_table: str,
     target_dataset: str,
     target_table: str,
+    oldest_allowable_target_partition: str,
     primary_keys=None,
     time_columns=None,
+    allow_partition_pruning: bool = True,
     timeout=DEFAULT_TIMEOUT,
     location=DEFAULT_LOCATION,
 ):
@@ -58,8 +60,10 @@ def deduplicate(
     :param source_table: source table id
     :param target_dataset: target dataset id
     :param target_table: target table id
+    :param oldest_allowable_target_partition: oldest value of time partition column value to be added to target table, aims to keep partition count below limit
     :param primary_keys: primary key columns of the source and target tables
     :param time_columns: time columns list to order rows
+    :param allow_partition_pruning: partition pruning allow parameter, if true prunes target table's partitions to limit query size
     :param timeout: query timeout duration parameter
     :param location: query location parameter
     :return:
@@ -73,67 +77,70 @@ def deduplicate(
     source_partition_field = get_time_partition_field(
         client, source_dataset, source_table
     )
-    target_partition_field = get_time_partition_field(
+    partition_pruning_params = dict()
+    partition_pruning_params["target_partition_field"] = get_time_partition_field(
         client, target_dataset, target_table
     )
-    oldest_target_partition = single_value_select(
-        client=client,
-        sql=get_oldest_partition_field_sql(
-            sql_file=GET_OLDEST_PARTITION_FIELD_SQL_FILE,
-            project_id=project_id,
-            target_dataset=target_dataset,
-            target_table=target_table,
-            source_dataset=source_dataset,
-            source_table=source_table,
-            target_partition_field=target_partition_field,
-            source_partition_field=source_partition_field,
-            start_date=buffered_start_date,
-            end_date=end_date,
-            primary_keys=primary_keys,
-        ),
-    )
-    if oldest_target_partition:
-        source_statement = get_deduplication_source_statement(
-            start_date=buffered_start_date,
-            end_date=end_date,
-            project_id=project_id,
-            source_dataset=source_dataset,
-            source_table=source_table,
-            source_partition_field=source_partition_field,
-            target_partition_field=target_partition_field,
-            oldest_target_partition=oldest_target_partition,
-            primary_keys=primary_keys,
-            time_columns=time_columns,
-        )
-        sql = get_merge_sql(
+    if allow_partition_pruning:
+        partition_pruning_params["oldest_target_partition"] = single_value_select(
             client=client,
-            project_id=project_id,
-            target_dataset=target_dataset,
-            target_table=target_table,
-            source_statement=source_statement,
-            primary_keys=primary_keys,
-            mode="DEDUPLICATE",
-            target_partition_field=target_partition_field,
-            oldest_target_partition=oldest_target_partition,
-        )
-        return query(
-            client=client,
-            job_config=bigquery.QueryJobConfig(),
-            sql=sql,
-            timeout=timeout,
-            location=location,
-        )
-    else:
-        LOGGER(
-            "There is no data: - {project_id}.{source_dataset}.{source_table} - between [{start_date} - {end_date}] .".format(
+            sql=read_sql(
+                sql_file=DEDUPLICATION_GET_OLDEST_PARTITION_FIELD_SQL_FILE,
                 project_id=project_id,
                 source_dataset=source_dataset,
                 source_table=source_table,
+                target_partition_field=partition_pruning_params[
+                    "target_partition_field"
+                ],
+                source_partition_field=source_partition_field,
                 start_date=buffered_start_date,
                 end_date=end_date,
-            )
+                oldest_allowable_target_partition=oldest_allowable_target_partition,
+            ),
         )
-        return None
+        if partition_pruning_params["oldest_target_partition"] is None:
+            LOGGER(
+                "There is no data: - {project_id}.{source_dataset}.{source_table} - between [{start_date} - {end_date}] .".format(
+                    project_id=project_id,
+                    source_dataset=source_dataset,
+                    source_table=source_table,
+                    start_date=buffered_start_date,
+                    end_date=end_date,
+                )
+            )
+            return None
+    source_statement = get_deduplication_source_statement(
+        start_date=buffered_start_date,
+        end_date=end_date,
+        project_id=project_id,
+        source_dataset=source_dataset,
+        source_table=source_table,
+        source_partition_field=source_partition_field,
+        primary_keys=primary_keys,
+        time_columns=time_columns,
+        oldest_allowable_target_partition=oldest_allowable_target_partition,
+        allow_partition_pruning=allow_partition_pruning,
+        partition_pruning_params=partition_pruning_params,
+    )
+    if not allow_partition_pruning:
+        partition_pruning_params.clear()
+    sql = get_merge_sql(
+        client=client,
+        project_id=project_id,
+        target_dataset=target_dataset,
+        target_table=target_table,
+        source_statement=source_statement,
+        primary_keys=primary_keys,
+        mode="UPSERT",
+        **partition_pruning_params
+    )
+    return query(
+        client=client,
+        job_config=bigquery.QueryJobConfig(),
+        sql=sql,
+        timeout=timeout,
+        location=location,
+    )
 
 
 def upsert(
@@ -280,7 +287,7 @@ def get_query_results(
     sql_file: str,
     sql_params: dict = None,
     timeout=DEFAULT_TIMEOUT,
-    location=DEFAULT_TIMEOUT,
+    location=DEFAULT_LOCATION,
 ):
     """
     Runs query and returns the result as dataframe
@@ -296,13 +303,12 @@ def get_query_results(
     if sql_params is None:
         sql_params = dict()
     sql = read_sql(sql_file=sql_file, **sql_params)
-    return query(
+    return select(
         client=client,
-        job_config=bigquery.QueryJobConfig(),
         sql=sql,
         timeout=timeout,
         location=location,
-    ).to_dataframe()
+    )
 
 
 def get_single_value_query_results(
@@ -310,7 +316,7 @@ def get_single_value_query_results(
     sql_file: str,
     sql_params: dict = None,
     timeout=DEFAULT_TIMEOUT,
-    location=DEFAULT_TIMEOUT,
+    location=DEFAULT_LOCATION,
 ):
     """
     Runs a single value returning query and returns the result
