@@ -5,15 +5,26 @@ here = os.path.abspath(os.path.dirname(__file__))
 
 
 ARCHIVE_DELETE_WHERE_STATEMENT_FILE = os.path.join(
-    here, "bigquery/archive/archive_delete_where_statement.sql"
+    here, "bigquery/archive/delete_where_statement.sql"
 )
 ARCHIVE_SOURCE_STATEMENT_FILE = os.path.join(
-    here, "bigquery/archive/archive_source_statement.sql"
+    here, "bigquery/archive/source_statement.sql"
+)
+DEDUPLICATION_GET_OLDEST_PARTITION_FIELD_SQL_FILE = os.path.join(
+    here, "bigquery/deduplication/get_oldest_partition_field.sql"
+)
+DEDUPLICATION_MERGE_KEYS_PARTITION_PRUNING_PARAMS = os.path.join(
+    here, "bigquery/deduplication/merge_keys_partition_pruning_params.sql"
 )
 DEDUPLICATION_SOURCE_STATEMENT_SQL_FILE = os.path.join(
-    here, "bigquery/deduplication/deduplication_source_statement.sql"
+    here, "bigquery/deduplication/source_statement.sql"
+)
+DEDUPLICATION_SOURCE_WHERE_STATEMENT_SQL_FILE = os.path.join(
+    here, "bigquery/deduplication/source_where_statement.sql"
+)
+DEDUPLICATION_SOURCE_WHERE_STATEMENT_PARTITION_PRUNING_PARAMS_SQL_FILE = os.path.join(
+    here, "bigquery/deduplication/source_where_statement_partition_pruning_params.sql"
 )
-DEDUPLICATION_SQL_FILE = os.path.join(here, "bigquery/deduplication/deduplicate.sql")
 DELETE_SQL_FILE = os.path.join(here, "bigquery/dml/delete.sql")
 GET_COLUMN_NAMES_SQL_FILE = os.path.join(
     here, "bigquery/information_schema/get_column_names.sql"
@@ -21,9 +32,6 @@ GET_COLUMN_NAMES_SQL_FILE = os.path.join(
 GET_OBJECT_FIELDS_SQL_FILE = os.path.join(
     here, "bigquery/information_schema/get_object_fields.sql"
 )
-GET_OLDEST_PARTITION_FIELD_SQL_FILE = os.path.join(
-    here, "bigquery/deduplication/get_oldest_partition_field.sql"
-)
 GET_TABLE_NAMES_SQL_FILE = os.path.join(
     here, "bigquery/information_schema/get_table_names.sql"
 )
