@@ -5,13 +5,15 @@ from airflow_commons.utils.file_utils import read_sql
 from airflow_commons.glossary import *
 from airflow_commons.sql_resources import (
     DEDUPLICATION_SOURCE_STATEMENT_SQL_FILE,
+    DEDUPLICATION_SOURCE_WHERE_STATEMENT_SQL_FILE,
+    DEDUPLICATION_SOURCE_WHERE_STATEMENT_PARTITION_PRUNING_PARAMS_SQL_FILE,
+    DEDUPLICATION_MERGE_KEYS_PARTITION_PRUNING_PARAMS,
     UPSERT_SQL_FILE,
     INSERT_SQL_FILE,
-    DEDUPLICATION_SQL_FILE,
     DELETE_SQL_FILE,
 )
 
-DML_MODES = ["INSERT", "UPSERT", "DEDUPLICATE"]
+DML_MODES = ["INSERT", "UPSERT"]
 
 
 def get_column_list_and_update_statements(
@@ -76,10 +78,11 @@ def get_deduplication_source_statement(
     source_dataset: str,
     source_table: str,
     source_partition_field: str,
-    target_partition_field: str,
-    oldest_target_partition: str,
     primary_keys: list,
     time_columns: list,
+    oldest_allowable_target_partition: str,
+    allow_partition_pruning: bool = True,
+    partition_pruning_params: dict = None,
 ):
     """
     Prepares deduplication source statement that will be used on deduplication process
@@ -90,26 +93,44 @@ def get_deduplication_source_statement(
     :param source_dataset: source dataset id
     :param source_table: source table id
     :param source_partition_field: source table's partition column name
-    :param target_partition_field: target table's partition column name
-    :param oldest_target_partition: oldest value of target table's partition column
     :param primary_keys: primary key column list
     :param time_columns: time columns list to order rows
+    :param oldest_allowable_target_partition: oldest allowed target time partitioning columns value
+    :param allow_partition_pruning: partition pruning allow parameter, if true prunes target table's partitions to limit query size
+    :param partition_pruning_params: dictionary of partition pruning params, has target_partition_field and oldest_target partition keys
     :return: formatted source statement
     """
+    if partition_pruning_params is None:
+        partition_pruning_params = dict()
     group_by_clause = get_primary_key_statements(primary_keys)["primary_key_list"]
     order_by_clause = get_order_by_statement(time_columns)
+    where_statement = read_sql(
+        sql_file=DEDUPLICATION_SOURCE_WHERE_STATEMENT_SQL_FILE,
+        source_partition_field=source_partition_field,
+        start_date=start_date,
+        end_date=end_date,
+        target_partition_field=partition_pruning_params["target_partition_field"],
+        oldest_allowable_target_partition=oldest_allowable_target_partition,
+    )
+    if allow_partition_pruning:
+        where_statement = (
+            where_statement
+            + WHITE_SPACE
+            + AND
+            + WHITE_SPACE
+            + read_sql(
+                sql_file=DEDUPLICATION_SOURCE_WHERE_STATEMENT_PARTITION_PRUNING_PARAMS_SQL_FILE,
+                **partition_pruning_params,
+            )
+        )
     return read_sql(
         sql_file=DEDUPLICATION_SOURCE_STATEMENT_SQL_FILE,
         order_by_clause=order_by_clause,
         project_id=project_id,
         source_dataset=source_dataset,
         source_table=source_table,
-        source_partition_field=source_partition_field,
-        start_date=start_date,
-        end_date=end_date,
-        target_partition_field=target_partition_field,
-        oldest_target_partition=oldest_target_partition,
         group_by_clause=group_by_clause,
+        source_where_statement=where_statement,
     )
 
 
@@ -138,7 +159,7 @@ def get_merge_sql(
     """
     if mode not in DML_MODES:
         raise ValueError(
-            "Invalide dml mode: {}. Acceptaple modes are ".format(mode)
+            "Invalid dml mode: {}. Acceptaple modes are ".format(mode)
             + COMMA.join(i for i in DML_MODES)
         )
     sql_params = get_column_list_and_update_statements(
@@ -149,8 +170,18 @@ def get_merge_sql(
     if mode == "INSERT":
         sql_params.pop("update_statements")
         sql_file = INSERT_SQL_FILE
-    elif mode == "DEDUPLICATE":
-        sql_file = DEDUPLICATION_SQL_FILE
+    elif bool(kwargs):
+        sql_params["merge_keys"] = (
+            read_sql(
+                DEDUPLICATION_MERGE_KEYS_PARTITION_PRUNING_PARAMS,
+                target_prefix=TARGET_PREFIX,
+                **kwargs,
+            )
+            + WHITE_SPACE
+            + AND
+            + WHITE_SPACE
+            + sql_params["merge_keys"]
+        )
     return read_sql(
         sql_file=sql_file,
         project_id=project_id,
@@ -158,51 +189,6 @@ def get_merge_sql(
         target_table=target_table,
         source_statement=source_statement,
         **sql_params,
-        **kwargs
-    )
-
-
-def get_oldest_partition_field_sql(
-    sql_file: str,
-    project_id: str,
-    target_dataset: str,
-    target_table: str,
-    source_dataset: str,
-    source_table: str,
-    target_partition_field: str,
-    source_partition_field: str,
-    start_date: str,
-    end_date: str,
-    primary_keys: list,
-):
-    """
-    Queries source table and returns the oldest value target table's partition column
-
-    :param sql_file: relative location of sql file
-    :param project_id: Bigquery project id
-    :param target_dataset: target dataset id
-    :param target_table: target table id
-    :param source_dataset: source dataset id
-    :param source_table: source table id
-    :param target_partition_field: time partitioning column of target table
-    :param source_partition_field: time partitioning column of source table
-    :param start_date: query start date
-    :param end_date: query end date
-    :param primary_keys: primary key columns of the source and target tables
-    :return:
-    """
-    return read_sql(
-        sql_file=sql_file,
-        project_id=project_id,
-        target_dataset=target_dataset,
-        target_table=target_table,
-        source_dataset=source_dataset,
-        source_table=source_table,
-        target_partition_field=target_partition_field,
-        source_partition_field=source_partition_field,
-        start_date=start_date,
-        end_date=end_date,
-        primary_key_list=get_primary_key_statements(primary_keys)["primary_key_list"],
     )
 
 
@@ -212,6 +198,15 @@ def get_delete_sql(
     table_id,
     where_statement,
 ):
+    """
+    Returns a delete dml query
+
+    :param project_id: Bigquery project id
+    :param dataset_id: dataset id
+    :param table_id: table id
+    :param where_statement: delete condition
+    :return: EmptyRowIterator
+    """
     return read_sql(
         sql_file=DELETE_SQL_FILE,
         project_id=project_id,
